@@ -1,11 +1,11 @@
-use warnings;
-use strict;
-
 package SVN::Hooks;
 {
-  $SVN::Hooks::VERSION = '1.25';
+  $SVN::Hooks::VERSION = '1.27';
 }
-# ABSTRACT: A framework for implementing Subversion hooks.
+# ABSTRACT: Framework for implementing Subversion hooks
+
+use strict;
+use warnings;
 
 use File::Basename;
 use File::Spec::Functions;
@@ -35,9 +35,11 @@ sub run_hook {
     foreach my $conf (@Conf_Files) {
 	my $conffile = file_name_is_absolute($conf) ? $conf : catfile($Repo, $conf);
 	next unless -e $conffile; # Configuration files are optional
+
+        # The configuration file must be evaluated in the main:: namespace
 	package main;
 {
-  $main::VERSION = '1.25';
+  $main::VERSION = '1.27';
 }
 	unless (my $return = do $conffile) {
 	    die "couldn't parse '$conffile': $@\n" if $@;
@@ -56,7 +58,7 @@ sub run_hook {
 	$repo_path = SVN::Look->new($repo_path, '-r' => $args[0]);
     }
 
-    foreach my $hook (values %{$Hooks{$hook_name}}) {
+    foreach my $hook (@{$Hooks{$hook_name}}) {
 	if (is_code_ref($hook)) {
 	    $hook->($repo_path, @args);
 	} elsif (is_array_ref($hook)) {
@@ -77,63 +79,72 @@ sub run_hook {
 
 sub POST_COMMIT (&) {
     my ($hook) = @_;
-    $Hooks{'post-commit'}{$hook} ||= sub { $hook->(@_); };
+    push @{$Hooks{'post-commit'}}, sub { $hook->(@_); };
+    return;
 }
 
 # post-lock(repos-path, username)
 
 sub POST_LOCK (&) {
     my ($hook) = @_;
-    $Hooks{'post-lock'}{$hook} ||= sub { $hook->(@_); };
+    push @{$Hooks{'post-lock'}}, sub { $hook->(@_); };
+    return;
 }
 
 # post-revprop-change(SVN::Look, username, property-name, action)
 
 sub POST_REVPROP_CHANGE (&) {
     my ($hook) = @_;
-    $Hooks{'post-revprop-change'}{$hook} ||= sub { $hook->(@_); };
+    push @{$Hooks{'post-revprop-change'}}, sub { $hook->(@_); };
+    return;
 }
 
 # post-unlock(repos-path, username)
 
 sub POST_UNLOCK (&) {
     my ($hook) = @_;
-    $Hooks{'post-unlock'}{$hook} ||= sub { $hook->(@_); };
+    push @{$Hooks{'post-unlock'}}, sub { $hook->(@_); };
+    return;
 }
 
 # pre-commit(SVN::Look)
 
 sub PRE_COMMIT (&) {
     my ($hook) = @_;
-    $Hooks{'pre-commit'}{$hook} ||= sub { $hook->(@_); };
+    push @{$Hooks{'pre-commit'}}, sub { $hook->(@_); };
+    return;
 }
 
 # pre-lock(repos-path, path, username, comment, steal-lock-flag)
 
 sub PRE_LOCK (&) {
     my ($hook) = @_;
-    $Hooks{'pre-lock'}{$hook} ||= sub { $hook->(@_); };
+    push @{$Hooks{'pre-lock'}}, sub { $hook->(@_); };
+    return;
 }
 
 # pre-revprop-change(SVN::Look, username, property-name, action)
 
 sub PRE_REVPROP_CHANGE (&) {
     my ($hook) = @_;
-    $Hooks{'pre-revprop-change'}{$hook} ||= sub { $hook->(@_); };
+    push @{$Hooks{'pre-revprop-change'}}, sub { $hook->(@_); };
+    return;
 }
 
 # pre-unlock(repos-path, path, username, lock-token, break-unlock-flag)
 
 sub PRE_UNLOCK (&) {
     my ($hook) = @_;
-    $Hooks{'pre-unlock'}{$hook} ||= sub { $hook->(@_); };
+    push @{$Hooks{'pre-unlock'}}, sub { $hook->(@_); };
+    return;
 }
 
 # start-commit(repos-path, username, capabilities)
 
 sub START_COMMIT (&) {
     my ($hook) = @_;
-    $Hooks{'start-commit'}{$hook} ||= sub { $hook->(@_); };
+    push @{$Hooks{'start-commit'}}, sub { $hook->(@_); };
+    return;
 }
 
 ## use critic
@@ -148,11 +159,11 @@ __END__
 
 =head1 NAME
 
-SVN::Hooks - A framework for implementing Subversion hooks.
+SVN::Hooks - Framework for implementing Subversion hooks
 
 =head1 VERSION
 
-version 1.25
+version 1.27
 
 =head1 SYNOPSIS
 
@@ -383,7 +394,8 @@ returning anything. Otherwise, they must C<die> with a suitable error
 message.
 
 Also note that each hook directive can be called more than once if you
-need to implement more than one specific hook.
+need to implement more than one specific hook. The hooks will run
+in the order they were defined.
 
 =head2 Using Plugins
 
